#
# spec file for package python-wheel
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-wheel%{psuffix}
Version:        0.45.1
Release:        2.1
Summary:        A built-package format for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pypa/wheel
Source:         https://github.com/pypa/wheel/archive/%{version}.tar.gz#/wheel-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/pypa/wheel/pull/651 fix test failures
Patch:          tests.patch
# Bootstrap: Don't BuildRequire setuptools or pip here!
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flit-core}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest >= 3.0.0}
BuildRequires:  %{python_module wheel >= %{version}}
%endif
%python_subpackages

%description
A built-package format for Python.

A wheel is a ZIP-format archive with a specially formatted filename
and the .whl extension. It is designed to contain all the files for a
PEP 376 compatible install in a way that is very close to the on-disk
format. Many packages will be properly installed with only the "Unpack"
step (simply extracting the file onto sys.path), and the unpacked archive
preserves enough information to "Spread" (copy data and scripts to their
final locations) at any later time.

%prep
%autosetup -p1 -n wheel-%{version}

%build
%if !%{with test}
%{python_expand # bootstrap with built-in pip
$python -m venv build/env
build/env/bin/python -m ensurepip
export PYTHONPATH=build/env/lib/python%{$python_bin_suffix}/site-packages
%{$python_pyproject_wheel}
}
%endif

%install
%if !%{with test}
%{python_expand # use pip bootstrapped above
export PYTHONPATH=build/env/lib/python%{$python_bin_suffix}/site-packages
%{$python_pyproject_install}
}
%python_clone -a %{buildroot}%{_bindir}/wheel
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export LC_ALL=en_US.utf8
export PYTHONDONTWRITEBYTECODE=1
# license tests failing with setuptools 77: https://github.com/pypa/wheel/issues/658
%pytest -k "not (test_licenses_default or test_licenses_deprecated or test_licenses_override)"
%endif

%if !%{with test}

%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative wheel

%post
%python_install_alternative wheel

%postun
%python_uninstall_alternative wheel

%files %{python_files}
%doc docs/news.rst README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/wheel
%{python_sitelib}/wheel-%{version}*-info
%{python_sitelib}/wheel/
%endif

%changelog
* Thu Mar 27 2025 Markéta Machová <mmachova@suse.com>
- Add tests.patch to fix (some) tests with setuptools 77
- Skip license tests failing with setuptools 77
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 0.45.1:
  * Fixed pure Python wheels converted from eggs and wininst
    files having the ABI tag in the file name
* Fri Nov 15 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.45.0
  * Refactored the ``convert`` command to not need setuptools to be installed
  * Don't configure setuptools logging unless running ``bdist_wheel``
  * Added a redirection from ``wheel.bdist_wheel.bdist_wheel`` to
    ``setuptools.command.bdist_wheel.bdist_wheel`` to improve compatibility with
    ``setuptools``' latest fixes.
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.44.0:
  * Canonicalized requirements in METADATA file
  * Deprecated the bdist_wheel module, as the code was migrated
    to setuptools itself
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.43.0:
  * Dropped support for Python 3.7
  * Updated vendored packaging to 24.0
* Fri Dec 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.42.0
  * Allowed removing build tag with wheel tags --build ""
  * Fixed wheel pack and wheel tags writing updated WHEEL fields
    after a blank line, causing other tools to ignore them
  * Fixed wheel pack and wheel tags writing WHEEL with CRLF line
    endings or a mix of CRLF and LF
  * Fixed wheel pack --build-number "" not removing build tag from
    WHEEL (above changes by Benjamin Gilbert)
- Release 0.41.3
  * Updated vendored packaging to 23.2
  * Fixed ABI tag generation for CPython 3.13a1 on Windows (PR by
    Sam Gross)
- Remove pip dependency for easier bootstrap
* Mon Sep  4 2023 Martin Schreiner <martin.schreiner@suse.com>
- Update to 0.41.2:
  - Changes from 0.41.2:
  * Fixed platform tag detection for GraalPy and 32-bit python
    running on an aarch64 kernel
  * Fixed wheel tags to not list directories in RECORD files
  * Fixed ABI tag generation for GraalPy
  - Changes from 0.41.1:
  * Fixed naming of the data_dir directory in the presence of local
    version segment given via egg_info.tag_build
  * Fixed version specifiers in Requires-Dist being wrapped in
    parentheses
  - Changes from 0.41.0:
  * Added full support of the build tag syntax to wheel tags
  * Fixed warning on Python 3.12 about onerror deprecation
  * Support testing on Python 3.12 betas
* Thu May  4 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.40.0:
  - Added a wheel tags command to modify tags on an existing
    wheel
  - Updated vendored packaging to 23.0
  - wheel unpack now preserves the executable attribute of
    extracted files
  - Fixed spaces in platform names not being converted to
    underscores
  - Fixed RECORD files in generated wheels missing the regular
    file attribute
  - Fixed DeprecationWarning about the use of the deprecated
    pkg_resources API
  - Wheel now uses flit-core as a build backend
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.38.4
  * Fixed PKG-INFO conversion in bdist_wheel mangling UTF-8 header values in METADATA (PR by Anderson Bravalheri)
- Update to version 0.38.3
  * Fixed install failure when used with --no-binary, reported on Ubuntu 20.04, by removing setup_requires from setup.cfg
* Sat Nov  5 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * require python >= 3.7
- update to version 0.38.2:
  * Fixed regression introduced in v0.38.1 which broke parsing of
    wheel file names with multiple platform tags
- changes from version 0.38.1:
  * Removed install dependency on setuptools
  * The future-proof fix in 0.36.0 for converting PyPy's SOABI into a
    abi tag was faulty. Fixed so that future changes in the SOABI will
    not change the tag.
- changes from version 0.38.0 (bsc#1206670, CVE-2022-40898):
  * obsoletes wheel_cve_2022_40898.patch in older dists
  * Dropped support for Python < 3.7
  * Updated vendored "packaging" to 21.3
  * Replaced all uses of "distutils" with "setuptools"
  * The handling of "license_files" (including glob patterns and
    default values) is now delegated to "setuptools>=57.0.0" (#466).
    The package dependencies were updated to reflect this change.
  * Fixed potential DoS attack via the "WHEEL_INFO_RE" regular
    expression
  * Fixed "ValueError: ZIP does not support timestamps before 1980"
    when using "SOURCE_DATE_EPOCH=0" or when on-disk timestamps are
    earlier than 1980-01-01. Such timestamps are now changed to the
    minimum value before packaging.
* Sat Oct 29 2022 Ben Greiner <code@bnavigator.de>
- Revert to 0.37.1
  * v0.38.0 has been yanked from PyPI
* Sat Oct 22 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * require python >= 3.8
  * update required version for setuptools
- update to version 0.38.0:
  * Dropped support for Python < 3.7
  * Updated vendored "packaging" to 21.3
  * Replaced all uses of "distutils" with "setuptools"
  * The handling of "license_files" (including glob patterns and
    default values) is now delegated to "setuptools>=57.0.0" (#466).
    The package dependencies were updated to reflect this change.
  * Fixed potential DoS attack via the "WHEEL_INFO_RE" regular
    expression
  * Fixed "ValueError: ZIP does not support timestamps before 1980"
    when using "SOURCE_DATE_EPOCH=0" or when on-disk timestamps are
    earlier than 1980-01-01. Such timestamps are now changed to the
    minimum value before packaging.
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 0.37.1:
  * Fixed ``wheel pack`` duplicating the ``WHEEL`` contents when the build
  number has changed Fixed parsing of file names containing commas in
  ``RECORD`` (PR by Hood Chatham)
  * Added official Python 3.10 support
  * Updated vendored ``packaging`` library to v20.9
- Also remove the conditional definition of python_module.
* Fri Jan 28 2022 Matej Cepl <mcepl@suse.com>
- When we limit setuptools in Requires, we should certainly do it
  in BuildRequires as well.
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Codify version requirement on setuptools for building.
* Tue Oct  5 2021 Stefan Schubert <schubi@suse.de>
- Added BuildRequires:  alts
* Fri Oct  1 2021 Stefan Schubert <schubi@suse.de>
- Use libalternatives instead of update-alternatives.
* Thu Jan 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.36.2:
  - Updated vendored ``packaging`` library to v20.8
  - Fixed wheel sdist missing ``LICENSE.txt``
  - Don't use default ``macos/arm64`` deployment target in calculating the
    platform tag for fat binaries (PR by Ronald Oussoren)
  - Fixed ``AssertionError`` when ``MACOSX_DEPLOYMENT_TARGET`` was set to ``11``
    (PR by Grzegorz Bokota and François-Xavier Coudert)
  - Fixed regression introduced in 0.36.0 on Python 2.7 when a custom generator
    name was passed as unicode (Scikit-build)
    (``TypeError: 'unicode' does not have the buffer interface``)
  - Added official Python 3.9 support
  - Updated vendored ``packaging`` library to v20.7
  - Switched to always using LF as line separator when generating ``WHEEL`` files
    (on Windows, CRLF was being used instead)
  - The ABI tag is taken from  the sysconfig SOABI value. On PyPy the SOABI value
    is ``pypy37-pp73`` which is not compliant with PEP 3149, as it should have
    both the API tag and the platform tag. This change future-proofs any change
    in PyPy's SOABI tag to make sure only the ABI tag is used by wheel.
  - Fixed regression and test for ``bdist_wheel --plat-name``. It was ignored for
    C extensions in v0.35, but the regression was not detected by tests.
  - Replaced install dependency on ``packaging`` with a vendored copy of its
    ``tags`` module
  - Fixed ``bdist_wheel`` not working on FreeBSD due to mismatching platform tag
    name (it was not being converted to lowercase)
  - Switched to the packaging_ library for computing wheel tags
  - Fixed a resource leak in ``WheelFile.open()`` (PR by Jon Dufresne)
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.34.2
  * Fixed installation of wheel from sdist on environments without Unicode file name support
  * Fixed installation of wheel from sdist which was broken due to a chicken and egg problem
  * Dropped Python 3.4 support
  * Moved the contents of setup.py to setup.cfg
* Mon Aug 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.33.6:
  * Don't add the m ABI flag to wheel names on Python 3.8 (PR by rdb)
  * Updated MANIFEST.in to include many previously omitted files in the sdist
  * Fixed egg2wheel compatibility with the future release of Python 3.10 (PR by Anthony Sottile)
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to mulitbuild to avoid dep on pytest by default
  (As pytest needs wheel to build itself)
* Fri Jun 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Reduce build requires and recommends to what is really needed
  (hint: almost nothing)
* Wed May 15 2019 Jonathan Harker <jharker@suse.com>
- Update to 0.33.4:
  * Fixed wheel build failures on some systems due to all attributes being preserved
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.33.1:
  * Fixed the ``--build-number`` option for ``wheel pack`` not being applied
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Remove build dependency on pytest-cov
- update to version 0.33.0
  * Added the `--build-number` option to the `wheel pack` command
  * Fixed bad shebangs sneaking into wheels
  * Fixed documentation issue with `wheel pack` erroneously being
    called `wheel repack`
  * Fixed filenames with "bad" characters (like commas) not being
    quoted in `RECORD` (PR by Paul Moore)
  * Sort requirements extras to ensure deterministic builds
* Fri Nov 23 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop not really needed %%license -> %%doc fallback
* Thu Nov 22 2018 Arun Persaud <arun@gmx.de>
- update to version 0.32.3:
  * Fixed compatibility with Python 2.7.0 – 2.7.3
  * Fixed handling of direct URL requirements with markers (PR by
    Benoit Pierre)
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- update to version 0.32.2:
  * Fixed build number appearing in the ".dist-info" directory name
  * Made wheel file name parsing more permissive
  * Fixed wrong Python tag in wheels converted from eggs (PR by John
    T. Wodder II)
* Fri Oct 12 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * remove sed/rm command for files that are not in the tar ball anymore
  * CHANGES.rst -> docs/news.rst
- update to version 0.32.1:
  * Fixed "AttributeError: 'Requirement' object has no attribute
    'url'" on setuptools/pkg_resources versions older than 18.8 (PR by
    Benoit Pierre)
  * Fixed "AttributeError: 'module' object has no attribute
    'algorithms_available'" on Python < 2.7.9 (PR by Benoit Pierre)
  * Fixed permissions on the generated ".dist-info/RECORD" file
- changes from version 0.32.0:
  * Removed wheel signing and verifying features
  * Removed the "wheel install" and "wheel installscripts" commands
  * Added the "wheel pack" command
  * Allowed multiple license files to be specified using the
    "license_files" option
  * Deprecated the "license_file" option
  * Eliminated duplicate lines from generated requirements in
    ".dist-info/METADATA" (thanks to Wim Glenn for the contribution)
  * Fixed handling of direct URL specifiers in requirements (PR by
    Benoit Pierre)
  * Fixed canonicalization of extras (PR by Benoit Pierre)
  * Warn when the deprecated "[wheel]" section is used in "setup.cfg"
    (PR by Jon Dufresne)
* Tue May 22 2018 arun@gmx.de
- specfile:
  * update copyright year
  * removed python-devel python-jsonschema
- update to version 0.31.1:
  * Fixed arch as "None" when converting eggs to wheels
- changes from version 0.31.0:
  * Fixed displaying of errors on Python 3
  * Fixed single digit versions in wheel files not being properly
    recognized
  * Fixed wrong character encodings being used (instead of UTF-8) to
    read and write "RECORD" (this sometimes crashed bdist_wheel too)
  * Enabled Zip64 support in wheels by default
  * Metadata-Version is now 2.1
  * Dropped DESCRIPTION.rst and metadata.json from the list of
    generated files
  * Dropped support for the non-standard, undocumented
    "provides-extra" and "requires-dist" keywords in setup.cfg
    metadata
  * Deprecated all wheel signing and signature verification commands
  * Removed the (already defunct) "tool" extras from setup.py
* Mon Nov 27 2017 idonmez@suse.com
- Fix homepage
- Resync the upstream tarball
* Sat Oct 14 2017 t.gruner@katodev.de
-  update to 0.30.0
* Fri Aug 11 2017 sebix+novell.com@sebix.at
- require python-setuptools (fixes boo#1037032)
* Thu Jul 20 2017 sebix+novell.com@sebix.at
- convert to singlespec
* Mon May  9 2016 hpj@urpla.net
- update to 0.29.0:
  * Fix compression type of files in archive (Issue #155, Pull Request #62,
  thanks Xavier Fernandez)
- update to 0.28.0:
  * Fix file modes in archive (Issue #154)
- update to 0.27.0:
  * Support forcing a platform tag using `--plat-name` on pure-Python wheels, as
    well as nonstandard platform tags on non-pure wheels (Pull Request #60, Issue
    [#144], thanks Andrés Díaz)
  * Add SOABI tags to platform-specific wheels built for Python 2.X (Pull Request
    [#55], Issue #63, Issue #101)
  * Support reproducible wheel files, wheels that can be rebuilt and will hash to
    the same values as previous builds (Pull Request #52, Issue #143, thanks
    Barry Warsaw)
  * Support for changes in keyring >= 8.0 (Pull Request #61, thanks Jason R.
    Coombs)
  * Use the file context manager when checking if dependency_links.txt is empty,
    fixes problems building wheels under PyPy on Windows  (Issue #150, thanks
    Cosimo Lupo)
  * Don't attempt to (recursively) create a build directory ending with `..`
    (invalid on all platforms, but code was only executed on Windows) (Issue #91)
  * Added the PyPA Code of Conduct (Pull Request #56)
- fix dependencies
* Wed Oct 21 2015 hpj@urpla.net
- actually, _really_ test this module:
  call py.test directly with appropriate PYTHONPATH
* Tue Sep 29 2015 tbechtold@suse.com
- update to 0.26.0:
  * Fix multiple entrypoint comparison failure on Python 3 (Issue #148)
  * Add Python 3.5 to tox configuration
  * Deterministic (sorted) metadata
  * Fix tagging for Python 3.5 compatibility
  * Support py2-none-'arch' and py3-none-'arch' tags
  * Treat data-only wheels as pure
  * Write to temporary file and rename when using wheel install --force
* Wed Apr  1 2015 benoit.monin@gmx.fr
- update to version 0.24.0:
  * The python tag used for pure-python packages is now .pyN (major
    version only). This change actually occurred in 0.23.0 when the
  - -python-tag option was added, but was not explicitly mentioned
    in the changelog then.
  * wininst2wheel and egg2wheel removed. Use "wheel convert
    [archive]" instead.
  * Wheel now supports setuptools style conditional requirements via
    the extras_require={} syntax. Separate 'extra' names from
    conditions using the : character. Wheel's own setup.py does
    this. (The empty-string extra is the same as install_requires.)
    These conditional requirements should work the same whether the
    package is installed by wheel or by setup.py.
- additional changes from 0.23.0:
  * Compatibiltiy tag flags added to the bdist_wheel command
  * sdist should include files necessary for tests
  * 'wheel convert' can now also convert unpacked eggs to wheel
  * Rename pydist.json to metadata.json to avoid stepping on the PEP
  * The --skip-scripts option has been removed, and not generating
    scripts is now the default. The option was a temporary approach
    until installers could generate scripts themselves. That is now
    the case with pip 1.5 and later. Note that using pip 1.4 to
    install a wheel without scripts will leave the installation
    without entry-point wrappers. The "wheel install-scripts"
    command can be used to generate the scripts in such cases.
  * Thank you contributors
- removed wininst2wheel and egg2wheel:
  they are not in 0.24.0 anymore
* Mon Feb 10 2014 speilicke@suse.com
- Fix update-alternatives usage
* Tue Sep 17 2013 dmueller@suse.com
- update to 0.22.0:
- Include entry_points.txt, scripts a.k.a. commands, in experimental
  pydist.json
- Improved test_requires parsing
- Python 2.6 fixes, "wheel version" command courtesy pombredanne
* Tue Sep 10 2013 toddrme2178@gmail.com
- Add BuildRequires:  python-argparse for SLE
* Tue Aug 13 2013 speilicke@suse.com
- Use upstream tarball
* Mon Aug 12 2013 speilicke@suse.com
- Initial version
